pub struct ApiGatewayV2RequestContext {
pub account_id: String,
pub api_id: String,
pub authorizer: HashMap<String, Value>,
pub domain_name: String,
pub domain_prefix: String,
pub http: Http,
pub request_id: String,
pub route_key: String,
pub stage: String,
pub time: String,
pub time_epoch: usize,
}Expand description
See context-variable-reference for more detail.
Fields
account_id: StringThe API owner’s AWS account ID.
api_id: StringThe identifier API Gateway assigns to your API.
The stringified value of the specified key-value pair of the context map returned from an API Gateway Lambda authorizer function.
domain_name: StringThe full domain name used to invoke the API. This should be the same as the incoming Host header.
domain_prefix: StringThe first label of the $context.domainName. This is often used as a caller/customer identifier.
http: HttpThe HTTP method used.
request_id: StringThe ID that API Gateway assigns to the API request.
route_key: StringUndocumented, could be resourcePath
stage: StringThe deployment stage of the API request (for example, Beta or Prod).
time: StringUndocumented, could be requestTime
time_epoch: usizeUndocumented, could be requestTimeEpoch